# Mscan

<img with="150px" height="150px" src="https://user-images.githubusercontent.com/61390950/182006521-350c306a-2567-49eb-b77a-42224783768f.png">  

## A modern network scanner
## 🖥 User Interface
![image](https://user-images.githubusercontent.com/61390950/216823967-a06601df-4d3f-41a2-9324-ca0c5c5b9a52.png)

## 💿 Installation
Install from pypi
```
pip3 install --upgrade modern-scan
```
## 🖥 Usage
Simply run the command mscan
```shell
$ mscan
Mscan running at http://127.0.0.1:8000/
```
## ✨ Features

- 🕹 Simple and clear user interface
- 🌐️️ Cross platform
- 🚀 Super fast
- 🛠 More features in development

## 🔌 API
Mscan offers an API which you can access at the following route:
```
/docs
```
This endpoint contains all the necessary information to get started with using the Mscan API in your software.
